@@ -1,4 +1,5 @@
-{-# LANGUAGE TupleSections #-}
+{-# LANGUAGE LambdaCase, TupleSections #-}
+{-# LANGUAGE TypeApplications #-}
 
 module Database.SmplstSQLite3 (
 	-- * Functions
@@ -128,11 +129,22 @@ instance SQLiteData () where
 	bindN = sqlite3BindNull
 	column _ _ = return ()
 
+instance SQLiteData Bool where
+	bindN stmt i = \case
+		False -> sqlite3BindInt stmt i 0
+		True -> sqlite3BindInt stmt i 1
+	column stmt i = (/= 0) <$> column @Int stmt i
+
 instance SQLiteData Int where
 	bindN = sqlite3BindInt
 	column (Stmt sm) i =
 		fromIntegral <$> c_sqlite3_column_int sm (fromIntegral i)
 
+instance SQLiteData Int64 where
+	bindN = sqlite3BindInt64
+	column (Stmt sm) i =
+		fromIntegral <$> c_sqlite3_column_int sm (fromIntegral i)
+
 instance SQLiteData Double where
 	bindN = sqlite3BindDouble
 	column (Stmt sm) i =
@@ -192,6 +204,11 @@ sqlite3BindInt (Stmt sm) i n = do
 	ret <- c_sqlite3_bind_int sm (fromIntegral i) (fromIntegral n)
 	when (ret /= sQLITE_OK) $ sqliteThrow "Cannot bind int" ret
 
+sqlite3BindInt64 :: Stmt -> Int -> Int64 -> IO ()
+sqlite3BindInt64 (Stmt sm) i n = do
+	ret <- c_sqlite3_bind_int sm (fromIntegral i) (fromIntegral n)
+	when (ret /= sQLITE_OK) $ sqliteThrow "Cannot bind int" ret
+
 sqlite3BindString :: Stmt -> Int -> String -> IO ()
 sqlite3BindString (Stmt sm) i s = withCString s $ \cs -> do
 	ret <- c_sqlite3_bind_text sm (fromIntegral i) cs (- 1) nullPtr
